@@ -1,7 +1,7 @@
 TEMPLATE_REPO_URLS = [
-    "git@github.com:luke-lombardi/slai_template.git",
-    "https://github.com/luke-lombardi/slai_template.git",
-]  # TODO: move to slai github
+    "git@github.com:slai-labs/slai_template.git",
+    "https://github.com/slai-labs/slai_template.git",
+]
 MODEL_WATCH_INTERVAL_S = 1
 LOCAL_CONFIG_PATH = ".slai/local_config.yml"
 GOOGLE_DRIVE_CONFIG_PATH = ".slai/google_drive_config.yml"
