@@ -16,7 +16,10 @@ class LocalConfigHelper:
         self.user_info = self.identity_client.get_user()
 
         self.drive_integration_enabled = False
-        if self.user_info["identity_user_google_auth"] is not None:
+        if (
+            self.user_info["identity_user_google_auth"] is not None
+            and self.user_info["identity_user_google_auth"]["enabled"]
+        ):
             self.drive_integration_enabled = True
             self.drive_client = DriveClient()
 
