@@ -1,9 +1,11 @@
 import base64
 import json
 import requests
+import git
 
 from pathlib import Path
 from requests.exceptions import HTTPError
+from git import Repo
 
 from slai_cli import log
 from slai_cli.modules.deployment_checks import check_handler_imports
@@ -108,6 +110,23 @@ def _create_model_deployment(*, model_client, model_version_id, docker_client):
     return model_deployment
 
 
+def _commit_deployment(*, model_name, model_version_name):
+    cwd = Path.cwd()
+    repo = Repo.init(cwd)
+    repo.git.add([f"models/{model_name}/*"])
+    repo.git.add([f"handlers/{model_name}/*"])
+    repo.index.commit(f"deployed model: {model_name}/{model_version_name}")
+
+    try:
+        log.action("Pushing state to git...")
+        repo.git.push("origin", "master")
+        log.action("Pushed to git.")
+    except (ValueError, git.exc.GitCommandError):
+        log.warn(
+            "WARNING: No remote is configured for this project, not pushing commits."
+        )
+
+
 @requires_slai_project
 def deploy_model(*, model_name, version):
     log.action("Deploying model to slai backend.")
@@ -160,10 +179,16 @@ def deploy_model(*, model_name, version):
         )
         if model_deployment is not None:
             log.action(
-                f"Created new model deployment:\n{json.dumps(model_deployment, sort_keys=True, indent=4)}"
+                f"Created new model deployment:\n{json.dumps(model_deployment, sort_keys=True, indent=4)}"  # noqa
             )
             log.action("Done.")
+
+            # commit changes to git repo
+            _commit_deployment(
+                model_name=model_name, model_version_name=model_version["name"]
+            )
+
     except InvalidHandlerSyntax:
         log.warn(
-            "ERROR: Cannot deploy a model handler with syntax/import errors, please check your handler.py"
+            "ERROR: Cannot deploy a model handler with syntax/import errors, please check your handler.py"  # noqa
         )
