@@ -10,14 +10,18 @@ from slai_cli.exceptions import InvalidApiKey
 from slai.modules.runtime import ValidRuntimes
 
 
-def get_credentials(profile_name="default", runtime=ValidRuntimes.Project):
+def get_credentials(
+    profile_name="default",
+    runtime=ValidRuntimes.Project,
+    client_id=None,
+    client_secret=None,
+):
     if runtime == ValidRuntimes.Local:
-        profile_name = click.prompt(
-            "Profile name", type=str, show_default=True, default=profile_name
-        )
+        profile_name = log.action(f"Configuring profile: {profile_name}")
 
-    client_id = click.prompt("Client ID", type=str)
-    client_secret = click.prompt("Client Secret", type=str)
+    if client_id is None or client_secret is None:
+        client_id = click.prompt("Client ID", type=str, default=client_id)
+        client_secret = click.prompt("Client Secret", type=str, default=client_secret)
 
     try:
         store_credentials(
